<?php
/*****************************************************************************
 * ManageTags.php
 * Contains the controller with the admin's list of tags.
 *
 * Kabuki CMS (C) 2013-2015, Aaron van Geffen
 *****************************************************************************/

class ManageTags extends HTMLController
{
	public function __construct()
	{
		// Ensure it's just admins at this point.
		if (!Registry::get('user')->isAdmin())
			throw new NotAllowedException();

		Session::resetSessionToken();

		$options = [
			'form' => [
				'action' => BASEURL . '/edittag/',
				'method' => 'get',
				'class' => 'col-md-6 text-end',
				'buttons' => [
					'add' => [
						'type' => 'submit',
						'caption' => 'Add new tag',
					],
				],
			],
			'columns' => [
				'id_tag' => [
					'value' => 'id_tag',
					'header' => 'ID',
					'is_sortable' => true,
				],
				'tag' => [
					'header' => 'Tag',
					'is_sortable' => true,
					'link' => BASEURL . '/edittag/?id={ID_TAG}',
					'value' => 'tag',
				],
				'slug' => [
					'header' => 'Slug',
					'is_sortable' => true,
					'link' => BASEURL . '/edittag/?id={ID_TAG}',
					'value' => 'slug',
				],
				'id_user_owner' => [
					'header' => 'Owning user',
					'is_sortable' => true,
					'format' => function($row) {
						if (!empty($row['id_user']))
							return sprintf('<a href="%s/edituser/?id=%d">%s</a>', BASEURL, $row['id_user'],
								$row['first_name'] . ' ' . $row['surname']);
						else
							return 'n/a';
					},
				],
				'count' => [
					'header' => 'Cardinality',
					'is_sortable' => true,
					'value' => 'count',
				],
			],
			'default_sort_order' => 'tag',
			'default_sort_direction' => 'up',
			'start' => $_GET['start'] ?? 0,
			'sort_order' => $_GET['order'] ?? '',
			'sort_direction' => $_GET['dir'] ?? '',
			'title' => 'Manage tags',
			'no_items_label' => 'No tags meet the requirements of the current filter.',
			'items_per_page' => 30,
			'index_class' => 'col-md-6',
			'base_url' => BASEURL . '/managetags/',
			'get_data' => function($offset, $limit, $order, $direction) {
				return Tag::getOffset($offset, $limit, $order, $direction, false);
			},
			'get_count' => function() {
				return Tag::getCount(false, null, false);
			}
		];

		$table = new GenericTable($options);
		parent::__construct('Tag management - Page ' . $table->getCurrentPage() .' - ' . SITE_TITLE);
		$this->page->adopt(new TabularData($table));
	}
}
